@@ -91,17 +91,32 @@ int create_seccomp_profile(bool cusetpm, unsigned int action)
         SCMP_SYS(settimeofday),
         SCMP_SYS(clock_adjtime),
         SCMP_SYS(clock_settime),
-#ifdef __NR_clock_settime64
+#ifdef __SNR_clock_settime64
         SCMP_SYS(clock_settime64),
 #endif
         SCMP_SYS(adjtimex),
-        SCMP_SYS(mount),
-        SCMP_SYS(umount2),
-#ifdef __NR_fsmount
+#ifdef __SNR_fsopen
+        SCMP_SYS(fsopen),
+#endif
+#ifdef __SNR_fsconfig
+        SCMP_SYS(fsconfig),
+#endif
+#ifdef __SNR_fsmount
         SCMP_SYS(fsmount),
 #endif
-#ifdef __NR_move_mount
+#ifdef __SNR_fspick
+        SCMP_SYS(fspick),
+#endif
+        SCMP_SYS(mount),
+#ifdef __SNR_move_mount
         SCMP_SYS(move_mount),
+#endif
+#if defined(__SNR_mount_setattr) && defined(__NR_mount_setattr)
+        SCMP_SYS(mount_setattr),
+#endif
+        SCMP_SYS(umount2),
+#ifdef __SNR_open_tree
+        SCMP_SYS(open_tree),
 #endif
         SCMP_SYS(swapon),
         SCMP_SYS(swapoff),
@@ -116,7 +131,7 @@ int create_seccomp_profile(bool cusetpm, unsigned int action)
         SCMP_SYS(delete_module), 
         SCMP_SYS(seccomp),
         SCMP_SYS(kexec_file_load),
-#ifdef __NR_sysctl
+#ifdef __SNR_sysctl
         SCMP_SYS(sysctl),
 #endif
         /* semaphores and messages queues */
@@ -153,6 +168,9 @@ int create_seccomp_profile(bool cusetpm, unsigned int action)
         SCMP_SYS(sethostname),
         SCMP_SYS(setdomainname),
         SCMP_SYS(quotactl),
+#if defined(__SNR_quotactl_fd) && defined(__NR_quotactl_fd)
+        SCMP_SYS(quotactl_fd),
+#endif
         SCMP_SYS(readahead),
         SCMP_SYS(lookup_dcookie),
         SCMP_SYS(add_key),
@@ -168,10 +186,10 @@ int create_seccomp_profile(bool cusetpm, unsigned int action)
         SCMP_SYS(signalfd),
         SCMP_SYS(eventfd),
         SCMP_SYS(timerfd_settime),
-#ifdef __NR_timer_settime64
+#ifdef __SNR_timer_settime64
         SCMP_SYS(timer_settime64),
 #endif
-#ifdef __NR_timerfd_settime64
+#ifdef __SNR_timerfd_settime64
         SCMP_SYS(timerfd_settime64),
 #endif
         SCMP_SYS(timerfd_gettime),
@@ -184,10 +202,10 @@ int create_seccomp_profile(bool cusetpm, unsigned int action)
         SCMP_SYS(acct),
         SCMP_SYS(prlimit64),
         SCMP_SYS(setrlimit),
-#ifdef __NR_bpf
+#ifdef __SNR_bpf
         SCMP_SYS(bpf),
 #endif
-#ifdef __NR_copy_filerange
+#ifdef __SNR_copy_filerange
         SCMP_SYS(copy_filerange),
 #endif
         /* xattrs */
@@ -203,7 +221,7 @@ int create_seccomp_profile(bool cusetpm, unsigned int action)
         SCMP_SYS(removexattr),
         SCMP_SYS(lremovexattr),
         SCMP_SYS(fremovexattr),
-        /* processs forking */
+        /* process forking */
         SCMP_SYS(execve),
         /* io */
         SCMP_SYS(iopl),
@@ -250,7 +268,7 @@ int create_seccomp_profile(bool cusetpm, unsigned int action)
         SCMP_SYS(fork),
         SCMP_SYS(vfork),
         SCMP_SYS(prctl),
-#ifdef __NR_clone3
+#ifdef __SNR_clone3
         SCMP_SYS(clone3),
 #endif
         /* misc */
